/*
 * Copyright (c) 2008, Your Corporation. All Rights Reserved.
 */

package au.net.ocean.maven.plugin.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * Populates the field with an instance of a Plexus component. This is like declaring a requirement in a Plexus component.
 * The default requirement will have a role equal to the declared type of the field, and will use the default role hint.
 * You can customise either of these by providing a role and/or roleHint parameter.
 * e.g. @component role="org.apache.maven.artifact.ArtifactHandler" roleHint="ear"
 * Note: This is identical to the deprecated form of parameter: @parameter expression="${component.yourpackage.YourComponentClass}".
 *
 * @author <a href="mailto:dave.whitla@ocean.net.au">Dave Whitla</a>
 * @version $Id: Component.java 0 6/04/2008 21:49:00 dwhitla $
 */
@Documented
@Target({ElementType.FIELD, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
public @interface Component {
    String role() default "";
    String roleHint() default "";
    String description() default "";
}
