/*******************************************************************************
 *
 * Copyright (c) 2007, Dave Whitla
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  * Neither the name of the copyright holder nor the names of contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

package au.net.ocean.maven.plugin.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;


/**
 * Created by dwhitla at Mar 30, 2007 10:38:18 PM
 *
 * @author <a href="mailto:dave.whitla@ocean.net.au">Dave Whitla</a>
 * @version $Id: MojoParameter.java 0 Mar 30, 2007 10:38:18 PM dwhitla $
 */
@Documented
@Target({ElementType.FIELD, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
public @interface Parameter {
    /**
     * Specifies an alias which can be used to configure this parameter from the POM. This is primarily useful to improve
     * user-friendliness, where Mojo field names are not intuitive to the user or are otherwise not conducive to configuration via
     * the POM.
     */
    String alias() default "";


    /**
     * Specifies the expression used to calculate the value to be injected into this parameter of the Mojo at buildtime.
     * This is commonly used to refer to specific elements in the POM, such as ${project.resources}, which refers to the list of
     * resources meant to accompany the classes in the resulting jar file. The default value is used when the expression evaluates
     * to null .
     * <p />
     * NOTE: If not specified, an expression of ${<name>} is assumed, which can only be satisfied from POM configuration or System
     * properties. The use of '${' and '}' is required to delimit actual expressions which may be evaluated.
     */
    String expression() default "";

    /**
     * Specifies the default value to be used when the <code>expression</code> evaluates to null .
     */
    String defaultValue() default "";

    /**
     * The description of this parameter's use inside the Mojo. Using the toolset, this is detected as the Javadoc description for the field.
     * <p />
     * NOTE: While this is not a required part of the parameter specification, it SHOULD be provided to enable future tool support
     * for browsing, etc. and for clarity.
     */
    String description() default "";

    String property() default "";
}
