/*
 * Copyright (c) 2008, Your Corporation. All Rights Reserved.
 */

package au.net.ocean.maven.plugin.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Specifies that this parameter cannot be configured directly by the user (as in the case of POM-specified configuration).
 * This is useful when you want to force the user to use common POM elements rather than plugin configurations, as in the case
 * where you want to use the artifact's final name as a parameter. In this case, you want the user to modify
 * <build><finalName/></build> rather than specifying a value for finalName directly in the plugin configuration section.
 * It is also useful to ensure that - for example - a List-typed parameter which expects items of type Artifact doesn't get a
 * List full of Strings.
 * NOTE: Specification of this annotation flags the parameter as non-editable; there is no true/false value.
 *
 * @author <a href="mailto:dave.whitla@ocean.net.au">Dave Whitla</a>
 * @version $Id: ReadOnly.java 0 6/04/2008 22:47:29 dwhitla $
 */
@Documented
@Target({ElementType.FIELD, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
public @interface ReadOnly {
}
